@@ -33,7 +33,7 @@ package Text::Template::Simple::Constants;
 use strict;
 use vars qw($VERSION $OID $DID @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
-$VERSION = '0.80';
+$VERSION = '0.81';
 
 # object fields
 BEGIN { $OID = -1 } # init object field id counter
@@ -311,7 +311,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 use Text::Template::Simple::Constants qw( :info DIGEST_MODS );
 use Carp qw( croak );
 
-$VERSION = '0.80';
+$VERSION = '0.81';
 
 BEGIN {
    if ( IS_WINDOWS ) {
@@ -539,7 +539,7 @@ use strict;
 use vars qw($VERSION);
 use Text::Template::Simple::Dummy;
 
-$VERSION = '0.80';
+$VERSION = '0.81';
 
 sub _compile { shift; return __PACKAGE__->_object->reval(shift) }
 
@@ -572,7 +572,7 @@ use overload q{""} => 'get';
 use Text::Template::Simple::Constants qw( MAX_FL RE_INVALID_CID );
 use Text::Template::Simple::Util      qw( LOG DEBUG DIGEST fatal );
 
-$VERSION = '0.80';
+$VERSION = '0.81';
 
 sub new {
    my $class = shift;
@@ -619,7 +619,7 @@ package Text::Template::Simple::Base::Parser;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '0.80';
+$VERSION = '0.81';
 
 use Text::Template::Simple::Util      qw(:all);
 use Text::Template::Simple::Constants qw(:all);
@@ -1009,7 +1009,7 @@ use vars qw($VERSION);
 use Text::Template::Simple::Util qw(:all);
 use Text::Template::Simple::Constants qw(:all);
 
-$VERSION = '0.80';
+$VERSION = '0.81';
 
 sub _include_no_monolith {
    # no monolith eh?
@@ -1198,7 +1198,7 @@ use vars qw($VERSION);
 use Text::Template::Simple::Util qw(:all);
 use Text::Template::Simple::Constants qw(:all);
 
-$VERSION = '0.80';
+$VERSION = '0.81';
 
 sub _examine {
    my $self   = shift;
@@ -1265,7 +1265,7 @@ use vars qw($VERSION);
 use Text::Template::Simple::Util qw(:all);
 use Text::Template::Simple::Constants qw(:all);
 
-$VERSION = '0.80';
+$VERSION = '0.81';
 
 sub _compiler { shift->[SAFE] ? COMPILER_SAFE : COMPILER }
 
@@ -1437,7 +1437,7 @@ package Text::Template::Simple::Tokenizer;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '0.80';
+$VERSION = '0.81';
 
 use constant CMD_CHAR             =>  0;
 use constant CMD_ID               =>  1;
@@ -1764,7 +1764,7 @@ use constant MY_IO_LAYER      => 0;
 use constant MY_INCLUDE_PATHS => 1;
 use constant MY_TAINT_MODE    => 2;
 
-$VERSION = '0.80';
+$VERSION = '0.81';
 
 sub new {
    my $class = shift;
@@ -1827,7 +1827,8 @@ sub slurp {
    my($fh, $seek);
    LOG(IO_SLURP => $file) if DEBUG();
 
-   if ( fileno $file ) {
+   # perl 5.5.3 compat: we need to check if it's a ref first
+   if ( ref $file && fileno $file ) {
       $fh   = $file;
       $seek = 1;
    }
@@ -1944,7 +1945,7 @@ use vars qw($VERSION);
 use Text::Template::Simple::Caller;
 use Text::Template::Simple::Util qw();
 
-$VERSION = '0.80';
+$VERSION = '0.81';
 
 sub stack { # just a wrapper
    my $opt = shift || {};
@@ -1960,7 +1961,7 @@ use strict;
 use vars qw($VERSION);
 use Text::Template::Simple::Dummy;
 
-$VERSION = '0.80';
+$VERSION = '0.81';
 
 sub _compile { shift; return eval shift }
 
@@ -1979,7 +1980,7 @@ use constant HINTS      => 8;
 use constant BITMASK    => 9;
 use Text::Template::Simple::Util qw( ishref fatal );
 
-$VERSION = '0.80';
+$VERSION = '0.81';
 
 sub stack {
    my $self    = shift;
@@ -2152,7 +2153,7 @@ use Text::Template::Simple::Constants qw(:all);
 use Text::Template::Simple::Util qw( DEBUG LOG ishref fatal );
 use Carp qw( croak );
 
-$VERSION = '0.80';
+$VERSION = '0.81';
 
 my $CACHE = {}; # in-memory template cache
 
@@ -2566,7 +2567,7 @@ package Text::Template::Simple;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '0.80';
+$VERSION = '0.81';
 
 use File::Spec;
 use Text::Template::Simple::Constants qw(:all);
@@ -2828,8 +2829,8 @@ generated with an automatic build tool. If you experience problems
 with this version, please install and use the supported standard
 version. This version is B<NOT SUPPORTED>.
 
-This document describes version C<0.80> of C<Text::Template::Simple>
-released on C<8 August 2009>.
+This document describes version C<0.81> of C<Text::Template::Simple>
+released on C<13 September 2009>.
 
 This is a simple template module. There is no extra template/mini 
 language. Instead, it uses Perl as the template language. Templates
